package webapp.dao.impl;

import java.sql.ResultSet;
import java.sql.SQLException;

import javax.sql.DataSource;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.EmptyResultDataAccessException;
import org.springframework.jdbc.core.RowMapper;
import org.springframework.jdbc.core.namedparam.MapSqlParameterSource;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.jdbc.core.namedparam.SqlParameterSource;
import org.springframework.stereotype.Repository;

import webapp.dao.UserDao;
import webapp.model.User;

@Repository
public class UserDaoImpl extends NamedParameterJdbcTemplate implements UserDao {

	@Autowired
	public UserDaoImpl(DataSource dataSource) {
		super(dataSource);
	}

	private final RowMapper<User> userRowMapper = new RowMapper<User>() {

		@Override
		public User mapRow(ResultSet rs, int rowNum) throws SQLException {
			String userId = rs.getString("user_id");
			String userName = rs.getString("user_name");
			String usingYn = rs.getString("using_yn");

			User user = new User();
			user.setId(userId);
			user.setName(userName);
			user.setUsing("Y".equals(usingYn) ? true : false);

			return user;
		}
	};

	private final String selectById = "select * from users where user_id = :id";

	@Override
	public User selectById(String id) {
		SqlParameterSource params = new MapSqlParameterSource("id", id);

		try {
			return queryForObject(this.selectById, params, this.userRowMapper);
		} catch (EmptyResultDataAccessException e) {
			return null;
		}
	}

}
